==> freecad_0.11.4446-dfsg.orig.tar.gz: FreeCAD-0.11.4446/src/Mod/Image/Gui/Resources/translations/Image_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location/>
      <source>Create image plane...</source>
      <translation>Napravi ravninu slike ...</translation>
    </message>
    <message>
      <location/>
      <source>create a planar image in the 3D space</source>
      <translation>stvoriti planarnu sliku u 3D prikazu</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <location/>
      <source>Open...</source>
      <translation>Otvori ...</translation>
    </message>
    <message>
      <location/>
      <source>Open image view</source>
      <translation>Otvori pogled slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>nedefinirani tip boja za gledanje slika</translation>
    </message>
    <message>
      <location/>
      <source>Image pixel format</source>
      <translation>format slike u pixelima</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location/>
      <source>&amp;Fit image</source>
      <translation>Prilagodi sliku</translation>
    </message>
    <message>
      <location/>
      <source>Stretch the image to fit the view</source>
      <translation>rastegni sliku da odgovara prikazu</translation>
    </message>
    <message>
      <location/>
      <source>&amp;1:1 scale</source>
      <translation>u mjerilu 1:1</translation>
    </message>
    <message>
      <location/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Prikaz slike u mjerilu 1:1</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Original color</source>
      <translation> I originalna boja</translation>
    </message>
    <message>
      <location/>
      <source>Display the image with its original color(s)</source>
      <translation>Prikaži sliku s originalnim bojama</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Brightened color</source>
      <translation>I  Razvedri boju</translation>
    </message>
    <message>
      <location/>
      <source>Display the image with brightened color(s)</source>
      <translation>Prikaži sliku s s izbjeljenim bojama</translation>
    </message>
    <message>
      <location/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location/>
      <source>Ready...</source>
      <translation>Spreman...</translation>
    </message>
    <message>
      <location/>
      <source>grey</source>
      <translation>siva</translation>
    </message>
    <message>
      <location/>
      <source>zoom</source>
      <translation>zum</translation>
    </message>
    <message>
      <location/>
      <source>outside image</source>
      <translation>izvan slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::Workbench</name>
    <message>
      <location/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location/>
      <source>Image viewer</source>
      <translation>Pregled slike</translation>
    </message>
    <message>
      <location/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Slike (*.png *.XPM *.jpg *.bmp)</translation>
    </message>
    <message>
      <location/>
      <source>Choose an image file to open</source>
      <translation>Odaberite koju ce te sliku otvoriti</translation>
    </message>
    <message>
      <location/>
      <source>Error open image</source>
      <translation>Pogreška pri otvaranju slike</translation>
    </message>
    <message>
      <location/>
      <source>Could not load the choosen image</source>
      <translation>Nije moguće učitati izabranu sliku</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
  </context>
</TS>

==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/Image/Gui/Resources/translations/Image_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <source>Create image plane...</source>
      <translation>Napravi ravninu slike ...</translation>
    </message>
    <message>
      <source>Create a planar image in the 3D space</source>
      <translation>Create a planar image in the 3D space</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>stvoriti planarnu sliku u 3D prikazu</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
    <message>
      <source>Open...</source>
      <translation>Otvori ...</translation>
    </message>
    <message>
      <source>Open image view</source>
      <translation>Otvori pogled slike</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+308"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>nedefinirani tip boja za gledanje slika</translation>
    </message>
    <message>
      <source>Image pixel format</source>
      <translation>format slike u pixelima</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>Prilagodi sliku</translation>
    </message>
    <message>
      <source>Stretch the image to fit the view</source>
      <translation>rastegni sliku da odgovara prikazu</translation>
    </message>
    <message>
      <source>&amp;1:1 scale</source>
      <translation>u mjerilu 1:1</translation>
    </message>
    <message>
      <source>Display the image at a 1:1 scale</source>
      <translation>Prikaz slike u mjerilu 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation> I originalna boja</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Prikaži sliku s originalnim bojama</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>I  Razvedri boju</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Prikaži sliku s s izbjeljenim bojama</translation>
    </message>
    <message>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <source>Ready...</source>
      <translation>Spreman...</translation>
    </message>
    <message>
      <source>grey</source>
      <translation>siva</translation>
    </message>
    <message>
      <source>zoom</source>
      <translation>zum</translation>
    </message>
    <message>
      <source>outside image</source>
      <translation>izvan slike</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Pregled slike</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+106"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Slike (*. png *. XPM *. jpg *. bmp)</translation>
    </message>
    <message>
      <source>Choose an image file to open</source>
      <translation>Odaberite koju ce te sliku otvoriti</translation>
    </message>
    <message>
      <source>Images</source>
      <translation>Images</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>All files</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Pogreška pri otvaranju slike</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nije moguće učitati izabranu sliku</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Slika</translation>
    </message>
  </context>
</TS>
